@@ -104,6 +104,9 @@ class DocManager(DocManagerBase):
     def commit(self):
         LOG.error("Commit")
 
+    def handle_command(self, doc, namespace, timestamp):
+        db = namespace.split('.', 1)[0]
+
     def nodeExist(self, name):
         matcher = NodeMatcher(self.graph)
         m = matcher.match().where(actorName=name).first()
